#
# spec file for package john
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         johndir %{_datadir}/john
%define         jumboversion john-1.9.0-jumbo-1
Name:           john
Version:        1.9.0
Release:        9.2
Summary:        Utility to detect weak passwords
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            https://www.openwall.com/john/
Source:         https://www.openwall.com/john/k/%{name}-%{version}.tar.xz
Source1:        https://www.openwall.com/john/k/%{name}-%{version}.tar.xz.sign
Source2:        %{name}.8.gz
Source3:        %{name}-rpmlintrc
Source6:        mailer.8
Source7:        relbench.8
Source8:        https://www.openwall.com/john/k/%{jumboversion}.tar.xz
Source9:        https://www.openwall.com/john/k/%{jumboversion}.tar.xz.sign
# PATCH-FIX-UPSTREAM cl-device.patch gh#openwall/john#4331
Patch0:         cl-device.patch
Patch1:         john-1.9.0-jumbo-gcc10.patch
Patch2:         john-1.9.0-jumbo-gcc11.patch
Patch3:         s390x-upstream.patch
Patch4:         s390x.patch
# PATCH-FIX-UPSTREAM https://github.com/openwall/john/pull/5309
Patch5:         john-1.9-python3.patch
BuildRequires:  dos2unix
BuildRequires:  gmp-devel
BuildRequires:  libpcap-devel
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(openssl)

%description
John the Ripper is a password cracker (password security auditing
tool). Its primary purpose is to detect weak passwords, and a
number of other hash types are supported to that end.

%prep
%setup -q -a8
cd %{jumboversion} && cp -a ./* ..
cd ..
rm -r %{jumboversion}
%autopatch -p1

# adapt the configs
perl -pi -e "s#Wordlist = (.*)#Wordlist = %{johndir}/password.lst#g" $RPM_BUILD_DIR/%{name}-%{version}/run/john.conf
perl -pi -e 's#^(\#define JOHN_SYSTEMWIDE_EXEC)\s.+$#$1\t\"%{johndir}\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define CFG_FULL_NAME)\s.+$#$1\t\"%{_sysconfdir}/john.conf\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define CFG_ALT_NAME)\s.+$#$1\t\"%{_sysconfdir}/john.conf\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define WORDLIST_NAME)\s.+$#$1\t\"%{johndir}/password.lst\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define LOG_NAME)\s.+$#$1\t\"%{_localstatedir}/log/john/john.log\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define JOHN_SYSTEMWIDE_HOME)\s.+$#$1\t\"%{johndir}\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h

%build
export CFLAGS="%{optflags} -fcommon"
pushd src
%configure --with-systemwide \
           --disable-openmp \
           --enable-fuzz \
           --enable-ztex=yes \
           --enable-experimental-code \
           --enable-pkg-config \
           --disable-native-tests
#ifarch x86_64
#            --enable-simd=avx \
#endif
%make_build -s clean
%make_build
popd
# fix shebang
sed -i 's|#!%{_bindir}/env perl|#!%{_bindir}/perl|' run/*.pl
sed -i 's|#! %{_bindir}/env perl|#!%{_bindir}/perl|' run/*.pl
sed -i 's|#!%{_bindir}/env python|#!%{_bindir}/python|' run/*.py
sed -i 's|#! %{_bindir}/env python|#!%{_bindir}/python|' run/*.py
sed -i 's|#!%{_bindir}/env perl|#!%{_bindir}/perl|' run/relbench

%install
mkdir -p %{buildroot}{%{_bindir},%{johndir},%{johndir}/wordlists,%{_sysconfdir},%{_mandir}/man8}
mkdir -p %{buildroot}%{_localstatedir}/log/john
install -m 755 run/john %{buildroot}%{_bindir}/
install -m 755 run/*.py %{buildroot}%{_bindir}/
install -m 755 run/*.pl %{buildroot}%{_bindir}/
install -m 755 run/un* %{buildroot}%{_bindir}/
install -m 755 run/*2john %{buildroot}%{_bindir}/
install -m 755 run/base64conv %{buildroot}%{_bindir}/
install -m 755 run/relbench %{buildroot}%{_bindir}/
install -m 755 -p run/mailer %{buildroot}%{_bindir}/
install -m 644 -p run/{password.lst,*.chr,d*.conf,h*.conf,k*.conf,r*.conf} %{buildroot}%{johndir}/
install -m 644 -p run/john.conf %{buildroot}%{_sysconfdir}/
touch %{buildroot}%{johndir}/john.local.conf
mkdir -p %{buildroot}%{_datadir}/john/kernels
cp -r run/kernels/* %{buildroot}%{_datadir}/john/kernels/
mkdir -p %{buildroot}%{_datadir}/john/rules
cp -r run/rules/* %{buildroot}%{_datadir}/john/rules/
# handle documentation - makes rpmlint happy
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp README.md  %{buildroot}%{_defaultdocdir}/%{name}/
cp -r doc/* %{buildroot}%{_defaultdocdir}/%{name}/
rm %{buildroot}%{_defaultdocdir}/%{name}/INSTALL
rm %{buildroot}%{_defaultdocdir}/%{name}/README
# install man pages
install -m 644 -p %{SOURCE2} %{buildroot}%{_mandir}/man8/
install -Dm644 %{SOURCE6} %{buildroot}%{_mandir}/man8/mailer.8
install -Dm644 %{SOURCE7} %{buildroot}%{_mandir}/man8/relbench.8
dos2unix %{buildroot}%{_defaultdocdir}/%{name}/README.krb5tgs-17-18-23.md

%files
%doc %{_defaultdocdir}/%{name}/
%{_mandir}/man8/john.8%{?ext_man}
%{_mandir}/man8/mailer.8%{?ext_man}
%{_mandir}/man8/relbench.8%{?ext_man}
%{_bindir}/*
%dir %{johndir}
%dir %{johndir}/kernels/
%{johndir}/kernels/*
%dir %{johndir}/rules/
%{johndir}/rules/*
%dir %{johndir}/wordlists
%attr(644,root,root) %{johndir}/password.lst
%attr(644,root,root) %{johndir}/*.chr
%attr(644,root,root) %{johndir}/d*.conf
%attr(644,root,root) %{johndir}/h*.conf
%attr(644,root,root) %{johndir}/k*.conf
%attr(644,root,root) %{johndir}/r*.conf
%config (noreplace) %{_sysconfdir}/john.conf
%config (noreplace) %{johndir}/john.local.conf
%attr(775,root,users) %dir %{_localstatedir}/log/john

%changelog
* Mon May  8 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add john-1.9-python3.patch to not require python2 anymore (boo#1210583)
- Use %%autopatch
* Thu Sep 15 2022 lars@linux-schulserver.de - 1.9.0
- disable enforcement of AVX support in the CPU: let john handle this
  during runtime automatically (bsc#1202318)
* Tue Oct 12 2021 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Upstream patch for Big Endians in s390x-upstream.patch
- Include johnswap.h in opencl_7z_fmt_plug.c with s390x.patch
* Tue Jun  8 2021 simmphonie@opensuse.org
- add john-1.9.0-jumbo-gcc11.patch to fix alignment compile errors
  on GCC 11 gh#4611
* Sat Mar 13 2021 Dirk Müller <dmueller@suse.com>
- enable ztex support (fix usb dependency):
  add john-1.9.0-jumbo-gcc10.patch to fix fcommon related build failures
* Tue Oct  6 2020 simmphonie@opensuse.org
- Add cl-device.patch to handle systems that already defined
  CL_DEVICE_TOPOLOGY_AMD  gh#4331
* Fri Jun 12 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
- Small cleanup of spec file with spec-cleaner
* Sat Oct 12 2019 simmphonie@opensuse.org
- Remove fdupes check (build fails with debug packages)
* Tue Sep 10 2019 simmphonie@opensuse.org
- Fixed build for ARM and PPC. CPU with AVX support at least is
  only available for x86_64 architecture now.
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Reword description to avoid
  unspecific "Unix password".
* Mon Sep  9 2019 simmphonie@opensuse.org
- remove setBadness from rpmlintrc
* Mon Sep  2 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the sources URL. Use https.
* Thu Jun  6 2019 simmphonie@opensuse.org
- spec-file changes
  + add jumbo scripts and remove "env" from shebang
  + remove patches. In upstream already:
    + john-1.7.9-powerpc_BE_need_rhash_u32_swap_copy.patch
    + ppc64le.patch
    + reproducible.patch
  + use configure to find dependenices and CPU architecture
    + openCL support
    + multicore support with fork option
    + require CPU with AVX support at least
  + root rights are no longer required
- update to 1.9.0
  + Increased the interleaving for bcrypt on x86-64 from 2x to 3x for a major
    speedup on CPUs without SMT.  Unfortunately, this sometimes results in a minor
    performance regression when running multiple threads on CPUs with SMT.
  + Recognize the $2b$ bcrypt prefix.
  + In the generic crypt(3) format, detect descrypt with valid vs. invalid salts
    as separate id's for our heuristics on supported hash types.
  + Introduced a number of optimizations for faster handling of large password
    hash files, including loading, cracking, and "--show".  Some of these use more
    memory than before, yet in a more efficient manner.
  + Benchmark using all-different candidate passwords of length 7 by default.
  + Dropped undocumented special handling of "Mc" in 'c' and 'C' rule commands.
  + Dropped undocumented limitation of the 'M' and 'Q' rule commands where they
    would sometimes memorize/check only up to the current hash type's length limit
    yet this optimization wouldn't necessarily be transparent (e.g., if a later
    command would extract a substring from above the hash type's length limit and
    bring it to within the limit).
  + Implemented special-case handling of repeated rule commands '$', '^', '[',
    ']', '{', and '}', as well as faster handling of the 'D' command.
  + When built with "--fork" support, disallow session names with all-digit
    suffixes since these clash with those produced by "--fork".
  + Forward SIGTERM to --fork'ed children.
  + Set stdout to line buffered (rather than potentially fully buffered), except
    for "--stdout", "--show", and auxiliary programs such as "unshadow".
  + On Windows, restore normal processing of Ctrl-C in case our parent (such as
    Johnny the GUI) had disabled it.
  + Added linux-x86*-avx512 and linux-x86*-avx2 make targets, which use
    respectively AVX-512 and AVX2 for bitslice DES.
  + Added linux-mic make target for Intel MIC (first generation Xeon Phi, aka
    Knights Corner), which uses its 512-bit SIMD intrinsics for bitslice DES.
    (For second generation Xeon Phi, aka Knights Landing, use linux-x86-64-avx512.)
  + Added linux-arm64le, linux-arm32le-neon, and linux-arm32le make targets.
    (The first two of these make use of ASIMD or NEON for bitslice DES.)
  + Added linux-sparc64 make target.
  + Made a minor optimization to MMX and SSE2 assembly code for LM hash.
  + Dropped Ultrix and SCO support.
  + Don't probe for alternate config file names (like john.ini when on Unix).
  + "DokuWiki" external mode sample has been added to the default john.conf.
  + Fixed operator precedence in the external mode compiler to be the same as C.
  + Fixed an out of bounds write bug in the external mode virtual machine.
  + Fixed a bug introduced in version 1.7.4 in the wordlist rules engine, where
    some sequences of rule commands could overflow a word buffer.
  + Fixed a bug where unaligned access SSE/AVX instructions would unnecessarily
    be generated by GCC 4.6+ in the bitslice DES code in non-OpenMP builds.
  + Fixed a bug where "Warning: no OpenMP support for this hash type" could be
    printed in "--stdout" mode.
  + Made assorted other bugfixes, portability and documentation enhancements.
- version 1.7.9.8
  + Revised the incremental mode to let the current character counts grow for
    each character position independently, with the aim to improve efficiency in
    terms of successful guesses per candidate passwords tested.
  + Revised the pre-defined incremental modes, as well as external mode filters
    that are used to generate .chr files.
  + Added makechr, a script to (re-)generate .chr files.
  + Enhanced the status reporting to include four distinct speed metrics (g/s,
    p/s, c/s, and C/s).
  + Added the "--fork=N" and "--node=MIN[-MAX]/TOTAL" options for trivial
    parallel and distributed processing.
  + In the external mode compiler, treat character literals as unsigned.
  + Renamed many of the formats.
  + Updated the documentation.
  + Relaxed the license for many source files to cut-down BSD.
  + Relaxed the license for John the Ripper as a whole from GPLv2 (exact version)
    to GPLv2 or newer with optional OpenSSL and unRAR exceptions.
  + Assorted other changes have been made.
* Tue Mar 27 2018 dimstar@opensuse.org
- Build against openSSL 1.0 until upstream catches up
  (boo#1078844).
* Sat May 27 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Thu Dec  8 2016 meissner@suse.com
- remove incorrect too large john.keyring ...
  The signature of these tarballs is currently with a key with MD5 hash,
  which is rejected by default.
* Wed Feb 17 2016 normand@linux.vnet.ibm.com
- as follow on of previous "jumbo patch" need two powerpc changes:
  new john-1.7.9-powerpc_BE_need_rhash_u32_swap_copy.patch
  place ppc64le.patch after application of "jumbo patch" in spec
  allow to solve partially boo #940498  for ppc64le
  but still have 4 FAILED tests for ppc64 tracked upstream by
  http://www.openwall.com/lists/john-dev/2016/02/16/1
* Thu Jun 25 2015 astieger@suse.com
- fix SLE 11 SP3 build
* Mon Dec 15 2014 lars@linux-schulserver.de
- include "jumbo patch" into the build - special thanks to
  Mark Draheim for the specfile patch (closes bnc #839246)
* Fri Jan 10 2014 dvaleev@suse.com
- Fix build on ppc64le
- added patches:
  * ppc64le.patch
* Mon Oct 28 2013 schwab@suse.de
- Use the generic target for m68k
* Wed Oct  9 2013 lars@linux-schulserver.de
- update to 1.8.0:
  + Revised the incremental mode to let the current character counts
    grow for each character position independently, with the aim to
    improve efficiency in terms of successful guesses per candidate
    passwords tested.
  + Revised the pre-defined incremental modes, as well as external
    mode filters that are used to generate .chr files.
  + Added makechr, a script to (re-)generate .chr files.
  + Enhanced the status reporting to include four distinct speed
    metrics (g/s, p/s, c/s, and C/s).
  + Added the "--fork=N" and "--node=MIN[-MAX]/TOTAL" options for
    trivial parallel and distributed processing.
  + In the external mode compiler, treat character literals as unsigned.
  + Renamed many of the formats.
  + Updated the documentation.
  + Relaxed the license for many source files to cut-down BSD.
  + Relaxed the license for John the Ripper as a whole from GPLv2
    (exact version) to GPLv2 or newer with optional OpenSSL and
    unRAR exceptions.
  + Assorted other changes have been made.
- add simple man pages for relbench and mailer scripts
- disable jumbo patch for now until a version for 1.8.0 is out
* Sun Mar 17 2013 schwab@suse.de
- Use the generic target for aarch64
* Sat Oct 20 2012 lars@linux-schulserver.de
- updated jumbo patch to 1.7.9-jumbo-7
* Fri Jul 13 2012 lars@linux-schulserver.de
- update to 1.7.9:
  + Added optional parallelization of the MD5-based crypt(3) code with OpenMP.
  + Added optional parallelization of the bitslice DES code with OpenMP.
  + Replaced the bitslice DES key setup algorithm with a faster one, which
    significantly improves performance at LM hashes, as well as at DES-based
    crypt(3) hashes when there's just one salt (or very few salts).
  + Optimized the DES S-box x86-64 (16-register SSE2) assembly code.
  + Added support for 10-character DES-based tripcodes (not optimized yet).
  + Added support for the "$2y$" prefix of bcrypt hashes.
  + Added two more hash table sizes (16M and 128M entries) for faster processing
    of very large numbers of hashes per salt (over 1M).
  + Added two pre-defined external mode variables: "abort" and "status", which
    let an external mode request the current cracking session to be aborted or the
    status line to be displayed, respectively.
  + Made some minor optimizations to external mode function calls and virtual
    machine implementation.
  + The "--make-charset" option now uses floating-point rather than 64-bit
    integer operations, which allows for larger CHARSET_* settings in params.h.
  + Added runtime detection of Intel AVX and AMD XOP instruction set extensions,
    with optional fallback to an alternate program binary.
  + Added relbench, a Perl script to compare two "john --test" benchmark runs,
    such as for different machines, "make" targets, C compilers, optimization
    options, or/and versions of John the Ripper.
  + Additional public lists of "top N passwords" have been merged into the
    bundled common passwords list, and some insufficiently common passwords were
    removed from the list.
  + Many minor enhancements and a few bug fixes were made.
- updated jumbo patch to 1.7.9-jumbo-6
- specfile cleanup (using spec-cleaner)
* Fri Sep 30 2011 joop.boonen@boonen.org
- Added a fix for the arm architecture, TARGET generic
* Fri Jul  8 2011 lars@linux-schulserver.de
- update to 1.7.8:
  + many changes, please see /usr/share/doc/packages/john/CHANGES
  + The bitslice DES S-box expressions have been replaced with those
    generated by Roman Rusakov specifically for John the Ripper
  + Added Intel AVX and AMD XOP instruction sets support for bitslice DES
  + Apache "$apr1$" MD5-based password hashes are now supported.
  + the loader now includes logic to warn the user of ambiguous
    hash encodings
  + "DateTime", "Repeats", "Subsets", "AtLeast1-Simple",
    "AtLeast1-Generic", and "Policy" external mode samples have been
    added to the default john.conf
  + A few minor bug fixes and enhancements were made
  + Corrected a logic error introduced in JtR 1.7.4.2: in
    "single crack" mode
- added and updated jumbo patch
* Tue Mar 15 2011 draht@suse.de
- go from jumbo patch 7 to 12
- needs -lm to link, via LDFLAGS from make command in spec
* Thu Sep  9 2010 lars@linux-schulserver.de
- update to 1.7.6:
  + Generic crypt(3) support (enabled with "--format=crypt") has been
    added for auditing password hash types supported by the system but
    not yet supported by John's own optimized cryptographic routines
    (such as "SHA-crypt" and SunMD5).
  + Optional parallelization of the above has been implemented by
    means of OpenMP along with glibc's crypt_r(3)
  + Optional parallelization of John's own optimized code for the
    OpenBSD-style Blowfish-based crypt(3) (bcrypt) hashes with OpenMP
    has been added
  + A more suitable version of 32-bit x86 assembly code for Blowfish
    is now chosen on Core i7 and similar CPUs (in 32 bit mode)
  + More optimal DES S-box expressions for PowerPC with AltiVec
  + The bitslice DES C source code has been reworked to allow for
    the use of arbitrary SIMD intrinsics, which was previously only
    implemented for AltiVec as a special case
  + Support for SSE2 and MMX intrinsics with bitslice DES (as an
    alternative to the supplied assembly code) has been added
    (currently only enabled for SSE2 on x86-64)
  + Support for mixed-type longer virtual vectors (such as SSE2+MMX,
    SSE2+ALU, AltiVec+ALU, and other combinations) with bitslice
    DES has been added
  + The loader will now detect password hashes specified on a line
    on their own, not only as part of an /etc/passwd or PWDUMP
    format file
  + When run in "--stdin" mode and reading candidate passwords from
    a terminal (to be typed by the user), John will no longer mess
    with the terminal settings
  + John will now restore terminal settings not only on normal
    termination or interrupt, but also when forcibly interrupted
    with two Ctrl-C keypresses
  + A new numeric variable has been added to the word mangling rules
    engine: "p" for position of the character last found with the
    "/" or "%%" commands
  + Support for the use of "--format" along with "--show" or
    "--make-charset" has been added
  + The choice of .rec and .log filenames for custom session names
    has been made more intuitive
  + Support for "\r" (character lists with repeats) and "\p0"
    (reference to the immediately preceding character list/range)
    has been added to the word mangling rules preprocessor
  + The undefined and undocumented behavior of some subtle word
    mangling rules preprocessor constructs has been changed to
    arguably be more sensible
* Thu Feb 11 2010 lrupp@suse.de
- update to 1.7.4.2:
  + Major performance improvements
  + John will now tend to use more memory to achieve better speed
  + Some previously missed common website passwords found on public
    lists of "top N passwords" have been added to the bundled common
    passwords list.
  + Support for back-references and "parallel" ranges has been
    added to the word mangling rules preprocessor.
  + The notion of numeric variables has been introduced into the
    rules engine.
  + New rule commands have been added
  + New rule reject flags have been added
  + The default rulesets for "single crack" and wordlist modes have
    been revised to make use of the new features, for speed, to
    produce fewer duplicates, and to attempt additional kinds of
    candidate passwords.
  + The default for the Idle setting has been changed from N to Y.
* Mon Feb  8 2010 jengelh@medozas.de
- only build MMX variant on >= i586
- guard TARGET=linux-x86-any with %%ix86
- enable building on sparcv9
* Mon Sep 28 2009 lrupp@suse.de
- update to 1.7.3.4:
  + "make check" has been implemented
  + The "--test" option will now take an optional argument - the
    duration of each benchmark in seconds
  + Some very minor bugs that did not affect normal operation have
    been fixed.
  + Some unimportant compiler warnings have been fixed, a source code
    comment has been made more verbose and more complete.
* Tue Sep  9 2008 lrupp@suse.de
- update to 1.7.3.1:
  + Two Blowfish-based crypt(3) hashes may now be computed in
    parallel for much better performance on modern multi-issue CPUs
    with a sufficient number of registers (e.g., x86_64).
  + New make targets: macosx-universal, macosx-x86-64, solaris-x86-64-cc,
    solaris-x86-64-gcc, solaris-x86-sse2-cc, solaris-x86-sse2-gcc,
    solaris-x86-mmx-cc, solaris-x86-mmx-gcc, solaris-x86-any-cc,
    linux-ia64;
  + Minor bug fixes.
  + "DumbForce" and "KnownForce" external mode samples have been
    added to the default john.conf.
- removed the outdated patchset (needs to be re-integrated)
* Mon Sep 25 2006 lrupp@suse.de
- remove double cflags definition
* Thu Jun  8 2006 lrupp@suse.de
- new version 1.7.2
- moved john.conf to /etc
- moved john binary to /usr/bin
- enabled some opt flags (must be tested)
* Wed May 17 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
- Fix last change.
* Mon Mar 27 2006 lrupp@suse.de
- use CFLAGS instead of params.h.patch
* Fri Mar 24 2006 lrupp@suse.de
- charset.tar.bz2 is included upstream
- reduce build requires
- new version 1.7.0.2
* Mon Mar 13 2006 lrupp@suse.de
- new version 1.7.0.1
- adapt patches to new version
- disabled some compiler fixes
- removed RPM_OPT_FLAGS => performance issue atm
* Mon Mar 13 2006 lrupp@suse.de
- split off worlists to an extra package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Fix ia64 configuration.
* Mon Dec 19 2005 aosthof@suse.de
- Fixed .spec file for all architectures besides x86
- Added targets for ia64 / s390 / s390x
* Fri Nov 11 2005 kukuk@suse.de
- Fix compiling with glibc 2.4 snapshot
* Wed Sep 14 2005 lrupp@suse.de
- new version 1.6.39
- use noreplace for config
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Sun Jun  5 2005 ro@suse.de
- added directory to filelist
* Fri Jun  3 2005 lrupp@suse.de
- changed manpage
- added patches from ftp.openwall.com again:
  + blowfish (Eggdrop blowfish)
  + md5 (work with md5 hash of apache; faster)
  + rawMD5
  + MySQL (about 75%% faster than mysqlpassword.c)
- enabled global mode in params.g again
* Mon May 30 2005 lrupp@suse.de
- added "all" wordlist from openwall
- enabled arch-support for sparc and ppc
- added old doc-files from 1.6
* Wed May 25 2005 lrupp@suse.de
- new package, version 1.6.38
* Tue Jan 25 2005 lrupp@suse.de
- added some wordlists to get more options ;-)
- added patches from ftp.openwall.com to provide support for
  additiional password formats:
  + blowfish
  + md5
  + rawMD5
* Mon Aug  2 2004 lrupp@suse.de
- - fixed BugTraq-ID: 43287
- enabled global-mode in params.h
- fix misspelling in manpage
* Fri Feb 27 2004 lrupp@suse.de
- use devel version: no segfault on x86-64
- included documentation and charsets from old version
- renamed new john.conf in john.ini
- created a short manpage for john
- created symlink /var/lib/john/john
* Mon Nov 10 2003 ro@suse.de
- use defattr
* Fri Nov  7 2003 lrupp@suse.de
- added '# norootforbuild' in the spec-file
* Thu Jun 12 2003 poeml@suse.de
- add /var/lib/john to the filelist
* Fri May 23 2003 coolo@suse.de
- use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul  5 2002 kukuk@suse.de
- use %%ix86
* Thu Mar 29 2001 uli@suse.de
- fixed for gcc >2.95
- replaced config.guess stuff with %%ifarch
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Mar 18 1999 uli@suse.de
- new package, version 1.6
